use caith::{RollResultType, Roller};
use rustyline::{config, history::DefaultHistory, Editor};
use std::ops::Deref;

fn main() {
    let rl_config = config::Builder::new().auto_add_history(true).build();
    let mut rl: Editor<(), DefaultHistory> = Editor::with_config(rl_config).unwrap();
    loop {
        let line = match rl.readline("> ") {
            Ok(line) => line,
            Err(_) => break,
        };

        let roller = Roller::new(line.trim());
        let roll = match roller {
            Ok(roll) => roll.roll(),
            Err(_) => {
                println!("Invalid input");
                continue;
            }
        };
        let result = match roll {
            Ok(res) => res,
            Err(_) => {
                println!("Invalid input");
                continue;
            }
        };

        match result.get_result() {
            RollResultType::Single(single) => {
                println!("{}", single.to_string(false));
            }
            RollResultType::Repeated(rep) => {
                for single in rep.deref() {
                    println!("{}", single.to_string(false));
                }
            }
        }
    }
}
